#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# *****************************************************************************
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Module authors:
#   Markus Zolliker <markus.zolliker@psi.ch>
# *****************************************************************************
"""Test command arguments"""

from secop.core import Module, Parameter, Command, FloatRange, StringType, BoolType, TupleOf, StructOf, ArrayOf


class TestCmd(Module):

    commands = {
        'arg':
            Command('5 args',
                    argument=TupleOf(StringType(), FloatRange(), BoolType(), TupleOf(BoolType()), StructOf(a=StringType())),
                    result=StringType()),
        'keyed':
            Command('keyworded arg', argument=StructOf(a=StringType(), b=FloatRange(), c=BoolType(), optional=['b']), result=StringType()),
        'one':
            Command('1 arg', argument=FloatRange(), result=StringType()),
        'none':
            Command('no arg', result=StringType()),
    }
    parameters = {
        'struct': Parameter('struct', StructOf(a=StringType(), b=FloatRange(), c=BoolType(), optional=['b']),
                            readonly=False, default=dict(a='',c=True)),
        'array': Parameter('array', ArrayOf(BoolType()),
                           readonly=False, default=[]),
        'tuple': Parameter('tuple', TupleOf(StringType(), FloatRange(), BoolType(), TupleOf(BoolType()), StructOf(a=StringType())),
                           readonly=False, default=('',0,False,(False,),dict(a=''))),
    }

    def do_arg(self, arg):
        return repr(arg)

    def do_keyed(self, arg):
        return repr(arg)

    def do_one(self, arg):
        return repr(arg)

    def do_none(self):
        return repr(None)
